==> haskell-loop-0.3.0-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-KOx5wj3pzTtDC2oyykMRO1
key: loop-0.3.0-KOx5wj3pzTtDC2oyykMRO1
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: ee5d2554d22dd3c0c8f916d1ccda3037
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/loop-0.3.0
hs-libraries: HSloop-0.3.0-KOx5wj3pzTtDC2oyykMRO1
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loop-0.3.0-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-LOzbklcRUOY5ogcFkY1222
key: loop-0.3.0-LOzbklcRUOY5ogcFkY1222
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: 8314e481c426346e9cf6eb435d6688d8
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/loop-0.3.0
hs-libraries: HSloop-0.3.0-LOzbklcRUOY5ogcFkY1222
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
